pub struct CurrentMatch {
pub target: String,
pub basename: String,
pub parent: PathBuf,
pub original: PathBuf,
}Fields
target: StringTarget name from config, or empty string if the file did not match any target and we fell back to the filename stem.
basename: Stringparent: PathBuforiginal: PathBufTrait Implementations
Sourceimpl Clone for CurrentMatch
impl Clone for CurrentMatch
Sourcefn clone(&self) -> CurrentMatch
fn clone(&self) -> CurrentMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CurrentMatch
impl Debug for CurrentMatch
Sourceimpl PartialEq for CurrentMatch
impl PartialEq for CurrentMatch
Sourcefn eq(&self, other: &CurrentMatch) -> bool
fn eq(&self, other: &CurrentMatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CurrentMatch
impl StructuralPartialEq for CurrentMatch